# Terraform Provider advawsroute53 (Terraform Plugin Framework)

The provider is used to manage the Route 53 zone record set, encompassing all records within the zone.

- A resource and a data source (`internal/provider/`),
- Examples (`examples/`) and generated documentation (`docs/`),
- Miscellaneous meta files.

## Requirements

- [Terraform](https://developer.hashicorp.com/terraform/downloads) >= 1.0
- [Go](https://golang.org/doc/install) >= 1.19

## Building The Provider

1. Clone the repository
1. Enter the repository directory
1. Build the provider using the Go `install` command:

```shell
go install
```

## Adding Dependencies

This provider uses [Go modules](https://go.dev/wiki/Modules).
Please see the Go documentation for the most up to date information about using Go modules.

To add a new dependency `github.com/author/dependency` to Terraform provider:

```shell
go get github.com/author/dependency
go mod tidy
```

Then commit the changes to `go.mod` and `go.sum`.

## Using the provider

```terraform
#reading records from yaml and building imdexes for them
locals {
  yaml_conf         = fileexists("./example.eu.yaml") ? yamldecode(file("./example.eu.yaml")) : null
  dns_zone_conf     = local.yaml_conf != null ? try(local.yaml_conf["dns_zone"], null) : null
  formatted_records = local.dns_zone_conf == null ? null : { for rec in local.dns_zone_conf : "${lower(trimsuffix(rec.name, "."))}_${rec.type}${can(rec.policy.id) ? "_${rec.policy.id}" : ""}" => rec }
}


resource "advawsroute53_recordset" "example" {
  zone_id    = "Z0620LMXTAX58HUKIEHP"
  record_set = local.formatted_records
}
```
